@@ -1,7 +1,7 @@
-CoordTransform <- proto(CoordCartesian, expr={
+CoordTrans <- proto(CoordCartesian, expr={
   
   muncher <- function(.) TRUE
-  munch <- function(., data, npieces=50) {
+  munch_group <- function(., data, npieces=50) {
     n <- nrow(data)
 
     x <- approx(data$x, n = npieces * (n - 1) + 1)$y
@@ -13,6 +13,13 @@ CoordTransform <- proto(CoordCartesian, expr={
     )
   }
   
+  munch <- function(., data, npieces=50) {
+    data <- add_group(data)
+    groups <- split(data, data$group)
+    munched_groups <- lapply(groups, function(df) .$munch_group(df, npieces))
+    do.call("rbind", munched_groups)
+  }
+  
   transform <- function(., data) {
     data$x <- .$xtr$transform(data$x)
     data$y <- .$ytr$transform(data$y)
