@@ -1,17 +1,27 @@
 GeomRibbon <- proto(GeomInterval, {
   default_stat <- function(.) StatIdentity
-  default_aes <- function(.) aes(colour="grey60", fill="grey80", size=1, linetype=1)
+  default_aes <- function(.) aes(colour="grey60", fill="grey80", size=0.5, linetype=1)
+  guide_geom <- function(.) "smooth"
 
   adjust_scales_data <- function(., scales, data) {
     if (!"y" %in% scales$input()) {
       scales$add(ScaleContinuous$new(variable="y"))  
     }
+
     y <- scales$get_scales("y")
     y$train(data$min)
+    y$train(data$y)
     y$train(data$max)
   }
 
+  # draw_legend <- function(., data, ...)  {
+  #   data <- aesdefaults(data, .$default_aes(), list(...))
+  # 
+  #   rectGrob(gp=gpar(col=data$colour, fill=data$fill))
+  # }
+
   draw <- function(., data, scales, coordinates, ...) {
+    data <- data[complete.cases(data[, c("x","min","max")]), ]
     tb <- with(data,
       coordinates$munch(data.frame(x=c(x, rev(x)), y=c(max, rev(min))))
     )
@@ -25,7 +35,7 @@ GeomRibbon <- proto(GeomInterval, {
       ggname("outline", polygonGrob(
         tb$x, tb$y,
         default.units="native",
-        gp=gpar(fill=NA, col=colour, lwd=size, lty=linetype)
+        gp=gpar(fill=NA, col=colour, lwd=size * .pt, lty=linetype)
       ))
     ))))
   }
@@ -63,8 +73,8 @@ GeomRibbon <- proto(GeomInterval, {
     (m <- m + geom_point())
     
     # The default summary isn't that useful
-    m + stat_summary(geom="ribbon")
-    m + stat_summary(geom="ribbon", fun=stat_median_hilow)
+    m + stat_summary(geom="ribbon", fun="range")
+    m + stat_summary(geom="ribbon", fun="median_hilow")
     
     # Use qplot instead
     qplot(year, level, data=huron, geom=c("area", "line"))
@@ -72,7 +82,7 @@ GeomRibbon <- proto(GeomInterval, {
 })
 
 GeomArea <- proto(GeomRibbon,{
-  default_aes <- function(.) aes(colour="grey60", fill="grey80", min=0, max=y, size=1, linetype=1)
+  default_aes <- function(.) aes(colour="grey60", fill="grey80", min=0, max=y, size=0.5, linetype=1)
   default_pos <- function(.) PositionStack
   required_aes <- c("x", "y", "min", "max")
 
