@@ -8,15 +8,15 @@ GeomSegment <- proto(Geom, {
     munched <- cbind(munched_starts, munched_ends[,c("xend", "yend")])
     with(munched, 
       segmentsGrob(x, y, xend, yend, default.units="native",
-      gp=gpar(col=colour, lwd=size, lty=linetype), arrow = arrow)
+      gp=gpar(col=colour, lwd=size * .pt, lty=linetype), arrow = arrow)
     )
   }
   
   adjust_scales_data <- function(., scales, data) {
-    rbind(
-      data,
-      transform(data, y = yend, x = xend)
-    )
+    scales$get_scales("x")$train(range(data$xend))
+    scales$get_scales("y")$train(range(data$yend))
+    
+    data
   }
   
   objname <- "segment"
@@ -34,7 +34,8 @@ GeomSegment <- proto(Geom, {
 
   default_stat <- function(.) StatIdentity
   required_aes <- c("x", "y", "xend", "yend")
-  default_aes <- function(.) aes(colour="black", size=0, linetype=1)
+  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1)
+  guide_geom <- function(.) "path"
   
   examples <- function(.) {
     require("maps")
