@@ -1,8 +1,8 @@
 
 ScaleIdentity <- proto(ScaleDiscrete, {  
   common <- c("colour","fill","size","shape","linetype")
-  new <- function(., name=NULL, breaks=NULL, labels=NULL, guide="point", variable="x") {
-    .$proto(name=name, .breaks=breaks, .labels=labels, .guide=guide, .input=variable, .output=variable)
+  new <- function(., name=NULL, breaks=NULL, labels=NULL, variable="x") {
+    .$proto(name=name, .breaks=breaks, .labels=labels, .input=variable, .output=variable)
   }
 
   guides.manual <- function(scale, ...) {
@@ -20,8 +20,6 @@ ScaleIdentity <- proto(ScaleDiscrete, {
   breaks <- function(.) .$.breaks
   labels <- function(.) .$.labels
 
-  guide_legend_geom <- function(.) Geom$find(.$.guide)
-  
   guide_legend <- function(.) {
     if (is.null(.$.labels)) return()
     .super$guide_legend(.)
@@ -41,7 +39,7 @@ ScaleIdentity <- proto(ScaleDiscrete, {
     # To get a legend, you also need to supply the labels to
     # be used on the legend, and the grob to draw them:
     # grob_tile, grob_line, or grob_point
-    qplot(1:4, 1:4, fill=colour, geom="tile") + scale_fill_identity(labels=letters[1:4], grob="tile", name="trt")
+    qplot(1:4, 1:4, fill=colour, geom="tile") + scale_fill_identity(labels=letters[1:4], guide="tile", name="trt")
     
     # cyl scaled to appropriate size
     qplot(mpg, wt, data=mtcars, size = cyl)
